translit-ua
===========

Transliteration for ukrainian language that uses officialy approved
rules

More about `Ukrainian National transliteration`_

.. _Ukrainian National transliteration: http://en.wikipedia.org/wiki/Romanization_of_Ukrainian
